<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="en_US">
<context>
    <name>CenterlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation type="vanished">无法矢量化层级 %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation type="vanished">无法矢量化没有帧的层级</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation type="vanished">无法矢量化图像 %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation type="vanished">不正确的参数(%1): 应该是图像或者层级</translation>
    </message>
</context>
<context>
    <name>FilePath</name>
    <message>
        <source>&quot;%1&quot;</source>
        <translation type="vanished">&quot;%1&quot;</translation>
    </message>
    <message>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation type="vanished">无法连接绝对路径: %1</translation>
    </message>
    <message>
        <source>%1 is not a directory</source>
        <translation type="vanished">%1 不是目录</translation>
    </message>
    <message>
        <source>can&apos;t read directory %1</source>
        <translation type="vanished">无法读取目录 %1</translation>
    </message>
</context>
<context>
    <name>Image</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="vanished">文件 %1 不存在</translation>
    </message>
    <message>
        <source>Loaded first frame of %1</source>
        <translation type="vanished">%1 的第一帧已经加载</translation>
    </message>
    <message>
        <source>Unexpected error while reading image</source>
        <translation type="vanished">读取图像时发生了意想不到的错误</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation type="vanished">未识别的文件类型:</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation type="vanished">无法将图像 %1 保存为该文件类型: %2</translation>
    </message>
    <message>
        <source>Unexpected error while writing image</source>
        <translation type="vanished">写入图像时发生了意想不到的错误</translation>
    </message>
</context>
<context>
    <name>ImageBuilder</name>
    <message>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation type="vanished">不正确的参数(%1): 应当是“光栅”或者“Toonz 光栅”</translation>
    </message>
    <message>
        <source>ImageBuilder(%1 image)</source>
        <translation type="vanished">图像生成器(%1 图像)</translation>
    </message>
    <message>
        <source>%1 : %2</source>
        <translation type="vanished">%1 : %2</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation type="vanished">不正确的参数(%1): 应当是几何变换</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>%1 frames</source>
        <translation type="vanished">%1 帧</translation>
    </message>
    <message>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation type="vanished">不正确的参数(%1): 应当是文件路径或者字符串</translation>
    </message>
    <message>
        <source>Exception loading level (%1)</source>
        <translation type="vanished">加载层级时的异常(%1)</translation>
    </message>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="vanished">文件 %1 不存在</translation>
    </message>
    <message>
        <source>File %1 is unsupported</source>
        <translation type="vanished">文件 %1 是不支持的</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation type="vanished">读取 %1 时的异常</translation>
    </message>
    <message>
        <source>Can&apos;t save an empty level</source>
        <translation type="vanished">无法保存空层级</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation type="vanished">未识别的文件类型:</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation type="vanished">不能保存层级 %1 为此文件类型：%2</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation type="vanished">写入 %1 时的异常</translation>
    </message>
    <message>
        <source>frame index (%1) must be a number</source>
        <translation type="vanished">帧索引(%1)必须是个数字</translation>
    </message>
    <message>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation type="vanished">帧索引(%1)超出范围(0-%2)</translation>
    </message>
    <message>
        <source>second argument (%1) is not an image</source>
        <translation type="vanished">第二个参数(%1)不是图像</translation>
    </message>
    <message>
        <source>can not insert a %1 image into a level</source>
        <translation type="vanished">无法插入图像 %1 到层级中</translation>
    </message>
    <message>
        <source>can not insert a %1 image to a %2 level</source>
        <translation type="vanished">无法插入图像 %1 到层级 %2 中</translation>
    </message>
</context>
<context>
    <name>OutlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation type="vanished">无法矢量化层级 %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation type="vanished">无法矢量化没有帧的层级</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation type="vanished">无法矢量化图像 %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation type="vanished">不正确的参数(%1): 应该是图像或者层级</translation>
    </message>
    <message>
        <source>Invalid color : </source>
        <translation type="vanished">无效的颜色: </translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <source>Retas Level Format</source>
        <translation>RETAS 层级格式</translation>
    </message>
    <message>
        <source>Adobe Photoshop</source>
        <translation></translation>
    </message>
    <message>
        <source>PNG</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>No restrictions for uncompressed avi video</source>
        <translation>不限制未压缩的 AVI 视频</translation>
    </message>
    <message>
        <source>video width must be a multiple of %1</source>
        <translation>视频宽度必须是 %1 的倍数</translation>
    </message>
    <message>
        <source>video length must be a multiple of %1</source>
        <translation>视频长度必须是 %1 的倍数</translation>
    </message>
    <message>
        <source>No restrictions for this codec</source>
        <translation>该编码不受限制</translation>
    </message>
    <message>
        <source>Resolution restrictions:</source>
        <translation>分辨率限制:</translation>
    </message>
    <message>
        <source>It is not possible to communicate with the codec.
 Probably the codec cannot work correctly.</source>
        <translation>无法调用编码器。
可能该编码器不能正常工作。</translation>
    </message>
    <message>
        <source>%1-%2</source>
        <translation>%1-%2</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Expected %1 argument(s) in %2, got %3</source>
        <translation>在 %2 中期待 %1 参数，实际有 %3</translation>
    </message>
    <message>
        <source>%1 is not a valid color (valid color names are &apos;red&apos;, &apos;transparent&apos;, &apos;#FF8800&apos;, ecc.)</source>
        <translation>%1 不是有效的颜色(有效的颜色名是类似“red”、“transparent”和“#FF8800”等等)</translation>
    </message>
    <message>
        <source>Vectorization failed</source>
        <translation>矢量化失败</translation>
    </message>
    <message>
        <source>Argument doesn&apos;t look like a file path : %1</source>
        <translation>参数不像是文件路径: %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image (not empty)</source>
        <translation>不正确的参数(%1): 必须指定图像(不能为空)</translation>
    </message>
    <message>
        <source>Argument &apos;%1&apos; does not look like a FrameId</source>
        <translation>参数 &apos;%1&apos;不像是帧 ID</translation>
    </message>
    <message>
        <source>First argument must be a scene : %1</source>
        <translation>第一个参数必须是场景: %1</translation>
    </message>
    <message>
        <source>Can&apos;t render empty scene</source>
        <translation>不能渲染空场景</translation>
    </message>
    <message>
        <source>New Camera  %1</source>
        <translation>新摄影机  %1</translation>
    </message>
    <message>
        <source>New Pegbar  %1</source>
        <translation>新定位尺  %1</translation>
    </message>
    <message>
        <source>Set Active Camera  %1 &gt; %2</source>
        <translation>设置启用的摄影机  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Remove Spline  %1</source>
        <translation>删除样条线  %1</translation>
    </message>
    <message>
        <source>New Motion Path  %1</source>
        <translation>新建运动路径  %1</translation>
    </message>
    <message>
        <source>Link Motion Path  %1 &gt; %2</source>
        <translation>链接运动路径  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Remove Object  %1</source>
        <translation>删除物体  %1</translation>
    </message>
    <message>
        <source>Remove Column  </source>
        <translation>删除列  </translation>
    </message>
    <message>
        <source>Load into Current Palette  &gt; %1</source>
        <translation>加载到当前调色板  &gt; %1</translation>
    </message>
    <message>
        <source>Replace with Current Palette  &gt; %1</source>
        <translation>用当前调色板替换  &gt; %1</translation>
    </message>
    <message>
        <source>Delete Studio Palette  : %1</source>
        <translation>删除工作室调色板  : %1</translation>
    </message>
    <message>
        <source>Create Studio Palette  : %1</source>
        <translation>创建工作室调色板  : %1</translation>
    </message>
    <message>
        <source>Delete Studio Palette Folder  : %1</source>
        <translation>删除工作室调色板文件夹  : %1</translation>
    </message>
    <message>
        <source>Create Studio Palette Folder  : %1</source>
        <translation>创建工作室调色板文件夹  : %1</translation>
    </message>
    <message>
        <source>Move Studio Palette Folder  : %1 : %2 &gt; %3</source>
        <translation>移动工作室调色板文件夹  : %1 : %2 &gt; %3</translation>
    </message>
    <message>
        <source>Arrange Styles  in Palette %1</source>
        <translation>在调色板 %1 中排列样式</translation>
    </message>
    <message>
        <source>Create Style#%1  in Palette %2</source>
        <translation>在调色板 %2 中创建样式#%1</translation>
    </message>
    <message>
        <source>Add Style  to Palette %1</source>
        <translation>添加样式到调色板 %1</translation>
    </message>
    <message>
        <source>Add Page %1 to Palette %2</source>
        <translation>添加页 %1 到调色板 %2</translation>
    </message>
    <message>
        <source>Delete Page %1 from Palette %2</source>
        <translation>从调色板 %2 中删除页 %1</translation>
    </message>
    <message>
        <source>Load Color Model %1  to Palette %2</source>
        <translation>加载色彩模型 %1 到调色板 %2</translation>
    </message>
    <message>
        <source>Move Page</source>
        <translation>移动页</translation>
    </message>
    <message>
        <source>Rename Page  %1 &gt; %2</source>
        <translation>重命名页  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Rename Style#%1 in Palette%2  : %3 &gt; %4</source>
        <translation>重命名调色板 %2 的样式#%1  : %3 &gt; %4</translation>
    </message>
    <message>
        <source>Add Fx  : </source>
        <translation>添加特效  : </translation>
    </message>
    <message>
        <source>Insert Fx  : </source>
        <translation>插入特效  : </translation>
    </message>
    <message>
        <source>Create Linked Fx  : %1</source>
        <translation>创建已链接的特效  : %1</translation>
    </message>
    <message>
        <source>Replace Fx  : </source>
        <translation>替换特效  : </translation>
    </message>
    <message>
        <source>Unlink Fx  : %1 - - %2</source>
        <translation>取消特效链接  : %1 - - %2</translation>
    </message>
    <message>
        <source>Make Macro Fx  : %1</source>
        <translation>制作宏特效  : %1</translation>
    </message>
    <message>
        <source>Explode Macro Fx  : %1</source>
        <translation>展开宏特效  : %1</translation>
    </message>
    <message>
        <source>Create Output Fx</source>
        <translation>创建输出特效</translation>
    </message>
    <message>
        <source>Connect to Xsheet  : </source>
        <translation>连接到摄影表  : </translation>
    </message>
    <message>
        <source>Disconnect from Xsheet  : </source>
        <translation>断开摄影表的连接 : </translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation>删除链接</translation>
    </message>
    <message>
        <source>Delete Fx Node : %1</source>
        <translation>删除特效节点 : %1</translation>
    </message>
    <message>
        <source>Paste Fx  :  </source>
        <translation>粘贴特效  :  </translation>
    </message>
    <message>
        <source>Disconnect Fx</source>
        <translation>断开特效的连接</translation>
    </message>
    <message>
        <source>Connect Fx : %1 - %2</source>
        <translation>连接特效 : %1 - %2</translation>
    </message>
    <message>
        <source>Rename Fx : %1 &gt; %2</source>
        <translation>重命名特效 : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Group Fx</source>
        <translation>组合特效</translation>
    </message>
    <message>
        <source>Ungroup Fx</source>
        <translation>解组特效</translation>
    </message>
    <message>
        <source>Rename Group  : %1 &gt; %2</source>
        <translation>重命名组  : %1 &gt; %2</translation>
    </message>
    <message>
        <source>Set Keyframe</source>
        <translation>设置关键帧</translation>
    </message>
    <message>
        <source>Remove Keyframe</source>
        <translation>移除关键帧</translation>
    </message>
    <message>
        <source>Cycle</source>
        <translation>循环</translation>
    </message>
    <message>
        <source>The autocentering failed on the current drawing.</source>
        <translation>在当前绘图上的自动定位中心点失败。</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>移动</translation>
    </message>
    <message>
        <source>Edit Rotation</source>
        <translation>编辑旋转</translation>
    </message>
    <message>
        <source>Move X</source>
        <translation>左右移动</translation>
    </message>
    <message>
        <source>Move Y</source>
        <translation>上下移动</translation>
    </message>
    <message>
        <source>Move Z</source>
        <translation>移动 Z 轴</translation>
    </message>
    <message>
        <source>Edit Stack Order</source>
        <translation>编辑堆栈顺序</translation>
    </message>
    <message>
        <source>Edit Scale W</source>
        <translation>编辑横向缩放</translation>
    </message>
    <message>
        <source>Edit Scale H</source>
        <translation>编辑纵向缩放</translation>
    </message>
    <message>
        <source>Edit Scale</source>
        <translation>编辑缩放</translation>
    </message>
    <message>
        <source>Edit PosPath</source>
        <translation>编辑位置路径</translation>
    </message>
    <message>
        <source>Edit Shear X</source>
        <translation>编辑横向切变</translation>
    </message>
    <message>
        <source>Edit Shear Y</source>
        <translation>编辑纵向切变</translation>
    </message>
    <message>
        <source>%1  %2  Frame : %3</source>
        <translation>%1  %2  帧 : %3</translation>
    </message>
    <message>
        <source>Set Keyframe   %1 at frame %2</source>
        <translation>设置关键帧   %1  在帧 %2</translation>
    </message>
    <message>
        <source>Remove Keyframe   %1 at frame %2</source>
        <translation>移除关键帧   %1  在帧 %2</translation>
    </message>
    <message>
        <source>Move Center   %1  Frame %2</source>
        <translation>移动中心   %1  帧 %2</translation>
    </message>
    <message>
        <source>color model</source>
        <translation>色彩模型</translation>
    </message>
    <message>
        <source>Set Picked Position of Style#%1 in Palette%2 : %3,%4</source>
        <translation>设定已经在调色板%2 : %3,%4中挑选的样式#%1位置</translation>
    </message>
    <message>
        <source>Update Colors by Using Picked Positions in Palette %1</source>
        <translation>使用在调色板%1中已经挑选的位置更新颜色</translation>
    </message>
    <message>
        <source>Can&apos;t save</source>
        <translation>没法保存</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>红</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>绿</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>蓝</translation>
    </message>
    <message>
        <source>DarkYellow</source>
        <translation>暗黄</translation>
    </message>
    <message>
        <source>DarkCyan</source>
        <translation>暗青</translation>
    </message>
    <message>
        <source>DarkMagenta</source>
        <translation>暗红</translation>
    </message>
    <message>
        <source>Brightness</source>
        <translation>亮度</translation>
    </message>
    <message>
        <source>Contrast</source>
        <translation>对比度</translation>
    </message>
    <message>
        <source>ColorThres</source>
        <translation>彩色阀值</translation>
    </message>
    <message>
        <source>WhiteThres</source>
        <translation>白色阀值</translation>
    </message>
    <message>
        <source>HRange</source>
        <translation>H范围</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>线条宽度</translation>
    </message>
    <message>
        <source>Toggle Autopaint Option  Palette : %1  Style#%2</source>
        <translation>启用/停止自动填充选项  调色板: %1  样式#%2</translation>
    </message>
    <message>
        <source>Can&apos;t undo rename palette</source>
        <translation>不能取消重命名调色板</translation>
    </message>
    <message>
        <source>Can&apos;t undo move palette</source>
        <translation>不能取消移动调色板</translation>
    </message>
    <message>
        <source>Can&apos;t redo rename palette</source>
        <translation>不能取消重命名调色板</translation>
    </message>
    <message>
        <source>Can&apos;t redo move palette</source>
        <translation>不能重做移动调色板</translation>
    </message>
    <message>
        <source>Rename Studio Palette : %1 &gt; %2</source>
        <translation>重命名工作室调色板  %1 &gt; %2</translation>
    </message>
    <message>
        <source>Xsheet</source>
        <translation>摄影表</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>时间轴</translation>
    </message>
    <message>
        <source>Failed to save the following resources:
</source>
        <translation>保存下面的资源失败:
</translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation>保存调色板失败。</translation>
    </message>
    <message>
        <source>and %1 more item(s).</source>
        <translation>和 %1 更多项目。</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>橙色</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>黄色</translation>
    </message>
    <message>
        <source>Light Green</source>
        <translation>浅绿色</translation>
    </message>
    <message>
        <source>Light Blue</source>
        <translation>浅蓝色</translation>
    </message>
    <message>
        <source>Dark Blue</source>
        <translation>深蓝色</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>紫色</translation>
    </message>
    <message>
        <source>Pink</source>
        <translation>粉色</translation>
    </message>
    <message>
        <source>Dark Pink</source>
        <translation>深粉色</translation>
    </message>
    <message>
        <source>White</source>
        <translation>白色</translation>
    </message>
</context>
<context>
    <name>Rasterizer</name>
    <message>
        <source>Expected a vector image: %1</source>
        <translation type="vanished">预期的矢量图像: %1</translation>
    </message>
    <message>
        <source>Expected a vector level: %1</source>
        <translation type="vanished">预期的矢量层级: %1</translation>
    </message>
    <message>
        <source>Argument must be a vector level or image : </source>
        <translation type="vanished">参数必须是矢量层级或图像: </translation>
    </message>
    <message>
        <source>%1 has no palette</source>
        <translation type="vanished">%1 没有调色板</translation>
    </message>
</context>
<context>
    <name>Scene</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation type="vanished">文件 %1 不存在</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation type="vanished">读取 %1 时的异常</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation type="vanished">写入 %1 时的异常</translation>
    </message>
    <message>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation type="vanished">不正确的层级类型(%1): 必须是矢量、光栅或者 Toonz 光栅</translation>
    </message>
    <message>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation type="vanished">无法添加层级: 名称(%1)已被使用</translation>
    </message>
    <message>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation type="vanished">无法加载此类文件作为层级: %1</translation>
    </message>
    <message>
        <source>Could not load level %1</source>
        <translation type="vanished">无法加载层级 %1</translation>
    </message>
    <message>
        <source>Level is not included in the scene : %1</source>
        <translation type="vanished">层级未包含在此场景: %1</translation>
    </message>
    <message>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation type="vanished">%1: 预期的层级矢量或者层级名</translation>
    </message>
    <message>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation type="vanished">层级 &apos;%1&apos; 没有在这个场景中</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::CenterlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>无法矢量化层级 %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>无法矢量化没有帧的层级</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>无法矢量化图像 %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>不正确的参数(%1): 应当是一个图像或层级</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::FilePath</name>
    <message>
        <source>&quot;%1&quot;</source>
        <translation>&quot;%1&quot;</translation>
    </message>
    <message>
        <source>can&apos;t concatenate an absolute path : %1</source>
        <translation>无法连接绝对路径: %1</translation>
    </message>
    <message>
        <source>%1 is not a directory</source>
        <translation>%1 不是目录</translation>
    </message>
    <message>
        <source>can&apos;t read directory %1</source>
        <translation>无法读取目录 %1</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Image</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>文件 %1 不存在</translation>
    </message>
    <message>
        <source>Loaded first frame of %1</source>
        <translation>%1 的第一帧已经加载</translation>
    </message>
    <message>
        <source>Unexpected error while reading image</source>
        <translation>读取图像时发生了意想不到的错误</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>无法识别的文件类型: </translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 image to this file type : %2</source>
        <translation>无法将图像 %1 保存为该文件类型: %2</translation>
    </message>
    <message>
        <source>Unexpected error while writing image</source>
        <translation>写入图像时发生了意想不到的错误</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ImageBuilder</name>
    <message>
        <source>Bad argument (%1): should be &apos;Raster&apos; or ToonzRaster&apos;</source>
        <translation>不正确的参数(%1): 应当是“光栅”或者“Toonz 光栅”</translation>
    </message>
    <message>
        <source>ImageBuilder(%1 image)</source>
        <translation>图像生成器(%1 图像)</translation>
    </message>
    <message>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a Transformation</source>
        <translation>不正确的参数(%1): 应当是几何变换</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Level</name>
    <message>
        <source>%1 frames</source>
        <translation>%1 帧</translation>
    </message>
    <message>
        <source>Bad argument (%1). It should be FilePath or string</source>
        <translation>不正确的参数(%1): 应当是文件路径或者字符串</translation>
    </message>
    <message>
        <source>Exception loading level (%1)</source>
        <translation>加载层级时的异常(%1)</translation>
    </message>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>文件 %1 不存在</translation>
    </message>
    <message>
        <source>File %1 is unsupported</source>
        <translation>文件 %1 是不支持的</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>读取 %1 时的异常</translation>
    </message>
    <message>
        <source>Can&apos;t save an empty level</source>
        <translation>无法保存空层级</translation>
    </message>
    <message>
        <source>Unrecognized file type :</source>
        <translation>无法识别的文件类型:</translation>
    </message>
    <message>
        <source>Can&apos;t save a %1 level to this file type : %2</source>
        <translation>不能保存层级 %1 为此文件类型：%2</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>写入 %1 时的异常</translation>
    </message>
    <message>
        <source>frame index (%1) must be a number</source>
        <translation>帧索引(%1)必须是个数字</translation>
    </message>
    <message>
        <source>frame index (%1) is out of range (0-%2)</source>
        <translation>帧索引(%1)超出范围(0-%2)</translation>
    </message>
    <message>
        <source>second argument (%1) is not an image</source>
        <translation>第二个参数(%1)不是图像</translation>
    </message>
    <message>
        <source>can not insert a %1 image into a level</source>
        <translation>无法插入图像 %1 到层级中</translation>
    </message>
    <message>
        <source>can not insert a %1 image to a %2 level</source>
        <translation>无法插入图像 %1 到层级 %2 中</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::OutlineVectorizer</name>
    <message>
        <source>Can&apos;t vectorize a %1 level</source>
        <translation>无法矢量化层级 %1</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a level with no frames</source>
        <translation>无法矢量化没有帧的层级</translation>
    </message>
    <message>
        <source>Can&apos;t vectorize a %1 image</source>
        <translation>无法矢量化图像 %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be an Image or a Level</source>
        <translation>不正确的参数(%1): 应当是图像或者层级</translation>
    </message>
    <message>
        <source>Invalid color : </source>
        <translation>无效的颜色: </translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Rasterizer</name>
    <message>
        <source>Expected a vector image: %1</source>
        <translation>预期的矢量图像: %1</translation>
    </message>
    <message>
        <source>Expected a vector level: %1</source>
        <translation>预期的矢量层级: %1</translation>
    </message>
    <message>
        <source>Argument must be a vector level or image : </source>
        <translation>参数必须是矢量层级或图像: </translation>
    </message>
    <message>
        <source>%1 has no palette</source>
        <translation>%1 没有调色板</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Scene</name>
    <message>
        <source>File %1 doesn&apos;t exist</source>
        <translation>文件 %1 不存在</translation>
    </message>
    <message>
        <source>Exception reading %1</source>
        <translation>读取 %1 时的异常</translation>
    </message>
    <message>
        <source>Exception writing %1</source>
        <translation>写入 %1 时的异常</translation>
    </message>
    <message>
        <source>Bad level type (%1): must be Vector,Raster or ToonzRaster</source>
        <translation>不正确的层级类型(%1): 必须是矢量、光栅或者 Toonz 光栅</translation>
    </message>
    <message>
        <source>Can&apos;t add the level: name(%1) is already used</source>
        <translation>无法添加层级: 名称(%1)已被使用</translation>
    </message>
    <message>
        <source>Can&apos;t load this kind of file as a level : %1</source>
        <translation>无法加载此类文件作为层级: %1</translation>
    </message>
    <message>
        <source>Could not load level %1</source>
        <translation>无法加载层级 %1</translation>
    </message>
    <message>
        <source>Level is not included in the scene : %1</source>
        <translation>层级未包含在此场景: %1</translation>
    </message>
    <message>
        <source>%1 : Expected a Level instance or a level name</source>
        <translation>%1: 预期的层级矢量或者层级名</translation>
    </message>
    <message>
        <source>Level &apos;%1&apos; is not included in the scene</source>
        <translation>层级 &apos;%1&apos; 没有在这个场景中</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::ToonzRasterConverter</name>
    <message>
        <source>Can&apos;t convert a %1 level</source>
        <translation>无法转换层级 %1</translation>
    </message>
    <message>
        <source>Can&apos;t convert a level with no frames</source>
        <translation>无法转换没有帧的层级</translation>
    </message>
    <message>
        <source>Can&apos;t convert a %1 image</source>
        <translation>无法转换图像 %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation>不正确的参数(%1): 应当是光栅层级或者光栅图像</translation>
    </message>
</context>
<context>
    <name>TScriptBinding::Transform</name>
    <message>
        <source>Identity</source>
        <translation>标识</translation>
    </message>
    <message>
        <source>Translation(%1,%2)</source>
        <translation>移动(%1,%2)</translation>
    </message>
    <message>
        <source>Rotation(%1)</source>
        <translation>旋转(%1)</translation>
    </message>
    <message>
        <source>Scale(%1%)</source>
        <translation>缩放(%1%)</translation>
    </message>
    <message>
        <source>Scale(%1%, %2%)</source>
        <translation>缩放(%1%, %2%)</translation>
    </message>
    <message>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation>几何变换(%1, %2, %3;  %4, %5, %6)</translation>
    </message>
</context>
<context>
    <name>ToonzRasterConverter</name>
    <message>
        <source>Can&apos;t convert a %1 level</source>
        <translation type="vanished">无法转换层级 %1</translation>
    </message>
    <message>
        <source>Can&apos;t convert a level with no frames</source>
        <translation type="vanished">无法转换没有帧的层级</translation>
    </message>
    <message>
        <source>Can&apos;t convert a %1 image</source>
        <translation type="vanished">无法转换图像 %1</translation>
    </message>
    <message>
        <source>Bad argument (%1): should be a raster Level or a raster Image</source>
        <translation type="vanished">不正确的参数(%1): 应当是光栅层级或者光栅图像</translation>
    </message>
</context>
<context>
    <name>Transform</name>
    <message>
        <source>Identity</source>
        <translation type="vanished">标识</translation>
    </message>
    <message>
        <source>Translation(%1,%2)</source>
        <translation type="vanished">移动(%1,%2)</translation>
    </message>
    <message>
        <source>Rotation(%1)</source>
        <translation type="vanished">旋转(%1)</translation>
    </message>
    <message>
        <source>Scale(%1%)</source>
        <translation type="vanished">缩放(%1%)</translation>
    </message>
    <message>
        <source>Scale(%1%, %2%)</source>
        <translation type="vanished">缩放(%1%, %2%)</translation>
    </message>
    <message>
        <source>Transform(%1, %2, %3;  %4, %5, %6)</source>
        <translation type="vanished">几何变换(%1, %2, %3;  %4, %5, %6)</translation>
    </message>
</context>
</TS>
